===================
FAN-C documentation
===================

.. toctree::
   :maxdepth: 3

   Getting started with FAN-C <getting_started>
   fanc: command line tools <fanc>
   fancplot: plotting from the command line <fancplot>
   Python API <api/api>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
